\NeedsTeXFormat{LaTeX2e}
% Archive of Mechanical Engineering Journal
% Available at: http://www.degruyter.com/view/j/meceng
% Available at: http://journals.pan.pl/ame
\ProvidesClass{amestyle_1.1}[2022/03/17 Archive of Mechanical Engineering]
\LoadClass[b5paper,11pt,twoside]{article}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                            %
%                             REQUIRED PACKAGES                              %
%                                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{textcase}     % FIXME: texlive-latex-recommended, is it portable?
\RequirePackage[fit]{truncate}% FIXME: texlive-latex-extra, is it portable?
\RequirePackage{etoolbox}     % FIXME: texlive-latex-extra, is it portable?
\RequirePackage{titlesec}     % FIXME: texlive-latex-extra, is it portable?
\RequirePackage{soul}         % FIXME: texlive-latex-extra, is it portable?
\RequirePackage{caption}      % FIXME: texlive-latex-recommended, is it portable?
\RequirePackage{iftex}        % FIXME: texlive-generic-extra, is it portable?
%\RequirePackage{tikz}         % For \foreach used for ORCID icon
%%%%%%%%%%%%%%%%%%%%%%%%% END OF REQUIRED PACKAGES %%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage[paperheight=246mm]{geometry}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                            %
%                SAVE COMMANDS THAT ARE TO BE REDEFINED                      %
%             (PLEASE KEEP THIS LIST SORTED ALPHABETICALLY)                  %
%                                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\let\ame@endtable\endtable
\let\ame@saved@abstract\abstract
\let\ame@saved@author\author
\let\ame@saved@endabstract\endabstract
\let\ame@saved@endenumerate\endenumerate
\let\ame@saved@enditemize\enditemize
\let\ame@saved@enumerate\enumerate
\let\ame@saved@footnote\footnote
\let\ame@saved@footnotemark\footnotemark
\let\ame@saved@footnotetext\footnotetext
\let\ame@saved@itemize\itemize
\let\ame@saved@maketitle\maketitle
\let\ame@saved@thanks\thanks
\let\ame@saved@title\title
\let\ame@table\table

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                            %
%                      DEFINITIONS OF CUSTOM COMMANDS                        %
%                                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amevolume
% A command for defining AME volume number.
% EXAMPLE: \amevolume{66}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amevolume}[1]{\gdef\@amevolume{#1}}
\def\@amevolume{{\tt\_\_}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ameissue
% A command for defining AME issue number.
% EXAMPLE: \ameissue{1}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ameissue}[1]{\gdef\@ameissue{#1}}
\def\@ameissue{{\tt\_}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ameyear
% A command for defining year of the volume/issue.
% EXAMPLE:  \ameyear{2019}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ameyear}[1]{\gdef\@ameyear{#1}}
\def\@ameyear{YEAR}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amejournal
% A command for defining journal title.
% EXAMPLE: \amejournal{ARCHIVE \hfil OF SILLY \hfil WALKS}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amejournal}[1]{\gdef\@amejournal{#1}}
\def\@amejournal{\sotyt{ARCHIVE  OF  MECHANICAL  ENGINEERING}}
\sodef\sotyt{}{.5em}{1.5em plus .3em minus .3em}{1.5em plus .3em minus .5em}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amedoi
% A command for defining DOI of the article.
% EXAMPLE: \amedoi{10.24425/ame.2019.123456}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amedoi}[1]{\gdef\@amedoi{#1}}
\def\@amedoi{{\tt\_\_.\_\_\_\_/\_\_\_.YYYY.\_\_\_\_\_\_}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amereceived
% A command for defining manuscript reception date
% EXAMPLE: \amereceived{September 09, 2018}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amereceived}[1]{\gdef\@amereceived{#1}}
\newcommand{\theamereceived}{\@amereceived}
\def\@amereceived{\_\_~\_\_\_\_\_\_\_~\_\_\_}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amereceived
% A command for defining manuscript reception date
% EXAMPLE: \amerevised{September 09, 2018}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amerevised}[1]{\gdef\@amerevised{#1}}
\newcommand{\theamerevised}{\@amereviseed}
\def\@amerevised{\_\_~\_\_\_\_\_\_\_~\_\_\_}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ameaccepted
% A command for defining manuscript acceptance date (final version)
% EXAMPLE: \ameaccepted{December 12, 2018}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ameaccepted}[1]{\gdef\@ameaccepted{#1}}
\newcommand{\theameaccepted}{\@ameaccepted}
\def\@ameaccepted{\_\_~\_\_\_\_\_\_\_~\_\_\_}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amepublished
% A command for defining manuscript reception date
% EXAMPLE: \amepublished{September 09, 2018}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amepublished}[1]{\gdef\@amepublished{#1}}
\newcommand{\theamepublished}{\@amepublished}
\def\@amepublished{\_\_~\_\_\_\_\_\_\_~\_\_\_}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \amepages
% A command for defining manuscript reception date
% EXAMPLE: \amepages{1-18}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\amepages}[1]{\gdef\@amepages{#1}}
\newcommand{\theamepages}{\@amepages}
\def\@amepages{\_\_\_--\_\_\_}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ameprintpage
% A command to define page number of the first page of the paper (as it would
% appear in a book of papers). This may be used when assembling a book from a
% series of compiled papers (PDFs e.g.).
% EXAMPLE: \ameprintpage{61}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ameprintpage}[1]{\setcounter{page}{#1}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \@ignorexxx
% Just ignore command's arguments. Used to replace a command with noop.
% EXAMPLE: \let\contact\@ignoreunr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\@ignoreunr}[1]{\null}     % command with one required argument
\newcommand{\@ignoreuno}[1][]{\null}   % command with one optional argument
\newcommand{\@ignorebinr}[2]{\null}    % command with two required arguments
\newcommand{\@ignorebino}[2][]{\null}  % command with one required and one optional argument


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \author
% A command for defining corresponding author, all authors and their affiliations
% EXAMPLE:
%   \author{%
%    \corrauthor{Gary Taylor, e-mail: \email{g.taylor@}}%
%                      contact to corrresponding author % [1]
%         John Smith%
%           \contact{Institute of Applied Sciences, Dublin, Ireland}% [2]
%           \and
%           Gary Taylor% 
%           \contactmark[2] % the same affilitation as contact [2]
%}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\author#1{%
  \ame@saved@author{#1}%
  \@ifundefined{@titleauthor@defined}{\titleauthor[N]{#1}}{}%
  \@ifundefined{@headauthor@defined}{\headauthor[N]{#1}}{}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \titleauthor
% A command for defining authors' names appearing in running titleers.
% By default, the value set with \author is used.
% EXAMPLE: \titleauthor{J. Smith \and G. Taylor}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\titleauthor}[2][]{%
\gdef\@titleauthor{#2}%
  \ifx&#1&\gdef\@titleauthor@defined{1}\fi%
}
\def\@titleauthor{\@latex@warning@no@line{Neither \noexpand\author nor \noexpand\titleauthor was given}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \headauthor
% A command for defining authors' names appearing in running headers.
% By default, the value set with \author is used.
% EXAMPLE: \headauthor{J. Smith \and G. Taylor}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\headauthor}[2][]{%
  \gdef\@headauthor{#2}%
  \ifx&#1&\gdef\@headauthor@defined{1}\fi%
}
\def\@headauthor{\@latex@warning@no@line{No \noexpand\headauthor given}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \title
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\title#1{%
  \ame@saved@title{#1}%
  \@ifundefined{@shorttitle@defined}{\shorttitle[N]{#1}}{}%
  \@ifundefined{@longtitle@defined}{\longtitle[N]{#1}}{}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \longtitle
% May be used to define long (main) title of the paper displayed on title page.
% EXAMPLE: \longtitle{Long title of the paper being submitted to Archive of Mechanical Engineering}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\longtitle}[2][]{%
  \gdef\@longtitle{#2}%
  \ifx&#1&\gdef\@longtitle@defined{1}\fi%
}
\def\@longtitle{\@latex@warning@no@line{No \noexpand\longtitle given}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \shorttitle
% May be used to define short title for several purposes (running headers).
% EXAMPLE: \shorttitle{Short title of the paper}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\shorttitle}[2][]{%
  \gdef\@shorttitle{#2}%
  \ifx&#1&\gdef\@shorttitle@defined{1}\fi%
  \@ifundefined{@headtitle@defined}{\headtitle[N]{#2}}{}%
}
\def\@shorttitle{\@latex@warning@no@line{No \noexpand\shorttitle given}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \headtitle
% May be used to define specific title for running headers. Defaults to \@shorttitle.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\headtitle}[2][]{%
  \gdef\@headtitle{#2}%
  \ifx&#1&\gdef\@headtitle@defined{1}\fi%
}
\def\@headtitle{\@latex@warning@no@line{No \noexpand\headtitle given}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \email
% Used to typeset corresponding author e-mail address. Other authors e-mails can also be added. If available, use \href to produce an interactive link.
% EXAMPLE: \email{corresponging.author@institute1.edu}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\email#1{\@ifundefined{href}{\texttt{#1}}{\href{mailto:#1}{#1}}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \contact
% Used to typeset author's contact information (affiliation).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\contact}[1]{\thanks{#1}} %


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \contactmark
% Used to refer to another author's affiliation/contact.
% EXAMPLE: \contactmark[2]  refers to first affifliation 
% (it is because [1] refers to corresponding author name and email)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\contactmark}[1][]{%
 \noindent\ifx&#1&\footnotemark\else\footnotemark[#1]\fi%
}

\def\@fnsymbol#1{\ensuremath{\ifcase#1\or {}\or 1\or 2\or 3\or 4\or 5\or \|\or **\or %
   \dagger %
   \or \ddagger\ddagger \else\@ctrerr\fi}} %


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%COMMAND: \corrauthor
%Used to typeset corresponding author name and email
%Must be set at the beginning of \author command
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\corrauthor}[1]{%
\contact{\!\!\!{\large\Letter}\ {#1}}}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAD: \orcidicon
% Used to produce ORCID icon
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\orcidicon}{\,\includegraphics[width=0.35cm]{orcid.pdf}\,}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAD: \orcidid
% Used to make link to author's ORCID account
% EXAMPLE: John Smith\orcidid{0000-0000-0000-000X} produces Orcid icon after author's name 
% and hyperlink to authors ORCID account
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\orcidid#1{\@ifundefined{href}{\texttt{#1}}{\href{https://orcid.org/#1}{\orcidicon}}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \doi
% Hyperlink to article with doi (used in bibliography)
% Example: doi: \doi{12.1234/...........}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\doi#1{\@ifundefined{href}{\texttt{#1}}{\href{https://doi.org/#1}{#1}}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%COMMAND: \license
% Used to show the conditions under which the article is published. 
% The text is set at the bottom of first page
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\license}{%
\footnotetext{
\begin{minipage}[t]{0.14\textwidth}
 \hspace{-1.5cc}\includegraphics[width=1.3\textwidth]{cc-by.png}
  \end{minipage}
  \begin{minipage}[b]{0.803\textwidth}
 \vspace*{9pt} 
\fontsize{7,5pt}{8,5pt}\selectfont\copyright\ \the\year. The Author(s). This is an open-access article distributed under the terms 
 of the Creative Commons Attribution (CC-BY 4.0,
 \href{https://creativecommons.org/licenses/by/4.0/}{https://creativecommons.org/licenses/by/4.0/}),
which permits use, distribution,  and reproduction in any medium, provided that the author and source are cited.
\end{minipage}}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \keywords
% Used to define keywords.
% EXAMPLE: \keywords{Key word one, key word two}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\keywords}[1]{\gdef\ame@keywords{#1}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ncc@thanks
% Like the \thanks command, but resistant to case change.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\ncc@thanks#1{\NoCaseChange{\ame@saved@thanks{#1}}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ncc@footnote
% Like the \footnotecommand, but resistant to case change.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ncc@footnote}[2][]{%
  \NoCaseChange{\ifx&#1&\ame@saved@footnote{#2}\else\ame@saved@footnote[#1]{#2}\fi}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ncc@footnotemark
% Like the \footnotemarkcommand, but resistant to case change.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ncc@footnotemark}[1][]{%
  \NoCaseChange{\ifx&#1&\ame@saved@footnotemark\else\ame@saved@footnotemark[#1]\fi}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ncc@footnotext
% Like the \footnotextcommand, but resistant to case change.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\ncc@footnotetext}[2][]{%
  \NoCaseChange{\ifx&#1&\ame@saved@footnotetext{#2}\else\ame@saved@footnotetext[#1]{#2}\fi}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \@maketitle
% The \@maketitle is used internally by \maketitle
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@maketitle{%
  \newpage
  \null\vskip3cc% zmiana z 5cc
   \begin{center}
%    \let\footnote\ncc@footnote
%    \let\footnotetext\ncc@footnotetext
%    \let\footnotemark\ncc@footnotemark
%    \let\thanks\ncc@thanks
      {%
      \fontsize{11dd}{14dd}\selectfont %
      \def\and{\unskip, }%
        {\@titleauthor}%
      \par%
       }%
    \vskip 20dd%

    {\fontsize{13,5dd}{15dd}\selectfont\bf{\@longtitle}\par}%

    \vskip 15dd% zmiana z 12dd
  \end{center}%
   \vskip 10dd% zmiana z 18dd
   
   {\noindent \fontsize{7.5dd}{8.5dd}\selectfont%
{\bf Received}\,\@amereceived, {\bf Revised}\,\@amerevised, {\bf Accepted}\,\@ameaccepted, {\bf  Published online}\,\@amepublished% 
 
             \vspace{5pt}
                 
\fontsize{8.5dd}{9.5dd}\selectfont\@ifundefined{ame@keywords}{}{\def\and{\unskip, }\noindent\textbf{Keywords:} \ame@keywords}}
  \vskip 10dd% dodane
} % end \@maketitle
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \maketitle
% The standard "article" class uses "empty" page style for the title page.
% This is hardcoded in the definition of \maketitle. For that reason, we
% redefine the \maketitle command to just add \thispagestyle{firstpage}.
%
% To alter the style of the first page, (re)define \ps@firstpage within our
% pagestyle definition -- \ps@ameheadings below.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\maketitle{\ame@saved@maketitle\thispagestyle{firstpage}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ifHeadingNumbered
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newif\ifHeadingNumbered
\ifx\l@nohyphenation\@undefined
        \newlanguage\l@nohyphenation
\fi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                            %
%                  CUSTOM ENVIRONMENTS                     %
%                                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ENVIRONMENT: abstract
% Redefine abstract environment
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\if@titlepage
  \renewenvironment{abstract}{%
      \titlepage
      \null\vfil
      \@beginparpenalty\@lowpenalty
     {\par\vfil\null\endtitlepage}
\else
  \renewenvironment{abstract}{%
      \if@twocolumn
        \section*{\abstractname}%
      \else
        \footnotesize
        \quotation
      \fi}
      {\if@twocolumn\else\endquotation\fi}
\fi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ENVIRONMENT: itemize, enumerate
% Redefine itemize environment
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{enumitem} %
\setlist{noitemsep,topsep=0pt,parsep=0pt,partopsep=0pt,labelindent=\parindent,leftmargin=*}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ENVIRONMENT: table
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{table}[1][]{%
  \ifx&#1&\ame@table\else\ame@table[#1]%
  \footnotesize%
}{%
  \ame@endtable%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ENVIRONMENT: acknowledgments
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\@ifundefined{acknowledgements}{%
  \newenvironment{acknowledgements}[1][]{%
    \ifx&#1&%
      \section*{\acknowledgementsname}
    \else%
      \section*{#1}
    \fi
  }{%
  }
}{}
\newcommand{\acknowledgementsname}{Acknowledgements}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \hf@amenormal
% Layout of a regular page (even/odd). This doesn't cover first (title) page.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\hf@amenormal}{%
  \def\@oddhead{\vtop{% odd pages
      \hb@xt@\textwidth{%
        \reset@font{\fontsize{8.5dd}{7dd}\selectfont
            \rlap{}\hfil
            \truncate{0.90\textwidth}{\@headtitle}}%
            \hfil\thepage\strut}%
      \vskip0.5dd\hrule\vskip-.9dd}}%!!!!
  \let\@oddfoot\@empty
  \def\@evenhead{\vtop{% even pages
      \hb@xt@\textwidth{%
        \let\thanks\@ignorebino%
        \let\footnote\@ignorebino%
        \let\footnotemark\@ignoreuno%
        \let\footnotetext\@ignorebino%
        \def\and{\unskip, }%
        \reset@font\strut\thepage\hfil
        \fontsize{8.5dd}{7dd}\selectfont
        \truncate{0.90\textwidth}{\@headauthor}%
        \hfil
        \llap{}}%
      \vskip1dd\hrule\vskip-1.4dd}}%
  \let\@evenfoot\@empty
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \hf@amefirstpage
% Defines the layout of the first (title) page.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\hf@amefirstpage}{%
  \def\@oddhead{%
    \fontsize{7.5dd}{7dd}%
    \selectfont{%
      \vtop{%
        \hb@xt@\textwidth{\@amejournal}%
        \vskip5dd\hrule\vskip-5.4dd
        \vspace{10dd}

        {%
          \fontsize{8dd}{9dd}\selectfont%
          \hb@xt@\textwidth{DOI: \@amedoi \hfill  \@ameyear, Vol. \@amevolume,  No. \@ameissue, pp. \@amepages}%
           \vspace{6pt}


        }%
      }%
    }%
  }

  \let\@oddfoot\@empty
  \let\@evenhead\oddhead
  \let\@evenfoot\@empty
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \ps@ameheadings
% Page style used for headings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\ps@ameheadings{%
  \let\@mkboth\markboth
  \let\ps@normal\hf@amenormal
  \let\ps@firstpage\hf@amefirstpage
  \let\ps@closing\hf@amenormal
  \let\ps@blank\hf@empty
  \ps@normal
  \def\sectionmark##1{%
    \markboth{%
      \ifHeadingNumbered \thesection.\enspace \fi
      ##1%
    }{}%
  }%
  \def\subsectionmark##1{%
    \markright{%
      \ifHeadingNumbered \thesubsection.\enspace \fi
      ##1%
    }%
  }%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                            %
%                                SETTINGS                              %
%                                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \pagestyle
% Use our predefined page style
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\pagestyle{ameheadings}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \footins
% Space between text body and the footnotes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\skip\footins}{12dd}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \footnoterule
% A bar over the footnote
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\footnoterule}{%
  \kern-6.5dd%
  \hrule\@width11cc\@height0.5dd%
  \kern6dd%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \normalsize
% Redefine normal text size
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand\normalsize{%
   \@setfontsize\normalsize{11pt}{13pt}%
   \abovedisplayskip 11\p@ \@plus3\p@ \@minus6\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 6.5\p@ \@plus3.5\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   }
\normalsize


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \parindent
% Paragraph indentation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\parindent}{1.5cc}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \textwidth
% Width of the text column
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\textwidth}{28cc}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \textheight
% Height of the text column
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\textheight}{555pt}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\widowpenalty=10000 
\clubpenalty=10000
% SET: \topnumber, \topfraction, ...
%
% These settings define how should floats (tables, figures, etc.) behave:
%   - topnumber:          maximum number of floats at top of page
%   - bottomnumber:       maximum number of floats at bottom of page
%   - totalnumber:        maximum number of floats on a page
%   -\topfraction:        maximum fraction of page for floats at top
%   -\bottomfraction:     maximum fraction of page for floats at bottom
%   -\textfraction:       minimum fraction of page for text
%   -\floatpagefraction:  minimum fraction of floatpage that should have floats
%   -\floatsep:           distance between two floats
%   -\textfloatsep:       distance between floats on the top or the bottom and
%                         the text
%   -\intextsep:          distance between floats inserted inside the page text
%                         (using h) and the text proper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand\topfraction{0.95}
\renewcommand\bottomfraction{0.95}
\renewcommand\textfraction{0.05}
\renewcommand\floatpagefraction{0.80}
\setlength{\floatsep}{10dd plus 2dd minus 2dd}
\setlength{\textfloatsep}{10dd plus 2dd minus 2dd}
\setlength{\intextsep}{10dd plus 2dd minus 2dd}
\setcounter{topnumber}{4}
\setcounter{bottomnumber}{4}
\setcounter{totalnumber}{4}
\setcounter{dbltopnumber}{4}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \topskip
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\topskip}{9pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \section
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\titleformat{\section}[block]%
  {\fontsize{11,6pt}{13,6pt}\bf}%
  {\thesection.}%
  {0.5em}%
  {\centering}
\titlespacing{\section}%
  {0pt}%
  {16\p@\@plus4\p@\@minus2\p@}%
  {12\p@\@plus2\p@\@minus2\p@}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \subsection
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\titleformat{\subsection}[block]%
  {\fontsize{11pt}{13pt}\bf}%
  {\thesubsection.}%
  {0.5em}%
  {\centering}
\titlespacing{\subsection}%
  {0pt}%
  {12\p@\@plus3\p@\@minus2\p@}%
  {10\p@\@plus0\p@\@minus0\p@}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \subsubsection
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\titleformat{\subsubsection}[block]%
  {\normalsize}%
  {\thesubsubsection.}%
  {0.5em}%
  {\centering}
\titlespacing{\subsubsection}%
  {0pt}%
  {12\p@\@plus3\p@\@minus2\p@}%
  {12\p@\@plus2\p@\@minus2\p@}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \frenchspacing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\frenchspacing

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \voffset
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength\voffset{0.25cm} 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SET: \headsep
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength\headheight{13pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SET: \headsep
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\headsep}{15pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SET: \marginparsep
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\marginparsep}{0pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SET: \marginparwidth
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\marginparwidth}{0pt}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SET: \footskip
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\footskip}{27pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SET: \marginparpush
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\marginparpush}{0pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \oddsidemargin, \evensidemargin
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\setlength{\oddsidemargin}{-1mm} %
\setlength{\evensidemargin}{-1mm} %

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \bibfont
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\bibfont{\footnotesize}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% COMMAND: \arraystretch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\arraystretch}{1.2}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SET: \pdfinclusioncopyfonts
% Workaround for pdfTeX.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ifPDFTeX
  \pdfinclusioncopyfonts=1
\fi



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                           CAPTION SETUP                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\DeclareCaptionLabelFormat{tablecaptionlabelfmt}{Table #2}
\DeclareCaptionLabelFormat{figurecaptionlabelfmt}{Fig. #2}

\captionsetup{
  font          = footnotesize,
  justification = centering,
  labelsep      = period
}
\captionsetup[table]{
  labelformat        = tablecaptionlabelfmt,
  skip          = {2pt plus 1pt minus 1pt},
  position      = top
}
\captionsetup[figure]{
  labelformat   = figurecaptionlabelfmt,
  position      = bottom
}
\captionsetup[subfigure]{
  font          = footnotesize,
  position      = bottom
}

\endinput
% vim: set expandtab spell tabstop=2 shiftwidth=2 syntax=tex ff=unix spelllang=en:
